@@ -12,7 +12,7 @@ use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 use POE::Component::IRC::Common qw(NORMAL DARK_GREEN DARK_BLUE ORANGE TEAL BROWN);
 use POE::Component::IRC::Plugin::FollowTail;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($package, %args) = @_;
@@ -118,6 +118,8 @@ sub _unrar_torrent {
 sub _erased_torrent {
     my ($self, $name, $size_bytes, $down_bytes, $up_bytes, $ratio) = @_;
     my $up = _fmt_bytes($up_bytes);
+    $ratio /= 1000 if $ratio != 0;
+    $ratio = sprintf '%.2f', $ratio;
 
     my $msg;
     if ($size_bytes == $down_bytes) {
